OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Vstavljeno sporočilo %s",
    "Important mail" : "Pomembno sporočilo",
    "No message found yet" : "Ni še najdenih sporočil",
    "Set up an account" : "Nastavi račun",
    "Unread mail" : "Neprebrana pošta",
    "Important" : "Pomembno",
    "Work" : "Službeno",
    "Personal" : "Osebno",
    "To Do" : "Naloge",
    "Later" : "Za kasneje",
    "Mail" : "Pošta",
    "You are reaching your mailbox quota limit for {account_email}" : "Kmalu bo dosežena omejitev prostora za račun {account_email}",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Trenutno uporabljate {percentage} dodaljenega prostora za poštni predal. Prostor lahko povečate z brisanjem nepotrebnih sporočil.",
    "Mails" : "Sporočila",
    "💌 A mail app for Nextcloud" : "💌 Poštni program za Nextcloud",
    "Your session has expired. The page will be reloaded." : "Seja je potekla. Stran bo samodejno osvežena.",
    "Drafts are saved in:" : "Osnutki se shranjujejo v:",
    "Sent messages are saved in:" : "Poslana sporočila se shranjujejo v:",
    "Deleted messages are moved in:" : "Izbrisana sporočila so premaknjena v:",
    "Archived messages are moved in:" : "Arhivirana sporočila so premaknjena v:",
    "Junk messages are saved in:" : "Neželena sporočila se shranjujejo v:",
    "Connecting" : "Poteka vzpostavljanje povezave ...",
    "Reconnect Google account" : "Ponovno poveži račun Google.",
    "Sign in with Google" : "Prijava z računom Google",
    "Save" : "Shrani",
    "Connect" : "Poveži",
    "Looking up configuration" : "Poteka preverjanje nastavitev",
    "Checking mail host connectivity" : "Preverjanje povezljivosti poštnega stražnika",
    "Configuration discovery failed. Please use the manual settings" : "Pridobivanje podatkov nastavitev je spodletelo. Vnesti jih je treba ročno.",
    "Password required" : "Zahtevano je geslo",
    "Testing authentication" : "Poteka overjanje podatkov",
    "Awaiting user consent" : "Čakanje na odziv uporabnika",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Račun je ustvarjen. Za povezavo Googlovega računa sledite navodilom.",
    "Loading account" : "Poteka nalaganje računa",
    "Account updated" : "Račun je posodobljen",
    "IMAP server is not reachable" : "Strežnik IMAP ni dosegljiv",
    "SMTP server is not reachable" : "Strežnik SMTP ni dosegljiv",
    "IMAP username or password is wrong" : "Uporabniško ime ali geslo IMAP je neveljavno",
    "SMTP username or password is wrong" : "Uporabniško ime ali geslo SMTP je neveljavno",
    "IMAP connection failed" : "Povezava IMAP je spodletela",
    "SMTP connection failed" : "Povezava SMTP je spodletela",
    "Auto" : "Samodejno",
    "Name" : "Ime",
    "Mail address" : "Elektronski naslov",
    "name@example.org" : "ime.priimek@primer.domena",
    "Please enter an email of the format name@example.com" : "Vpišite elektronski naslov v obliki ime.priimek@primer.domena.",
    "Password" : "Geslo",
    "Manual" : "Ročno",
    "IMAP Settings" : "Nastavitve IMAP",
    "IMAP Host" : "Gostitelj IMAP",
    "IMAP Security" : "Varnost IMAP",
    "None" : "Brez",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Vrata IMAP",
    "IMAP User" : "Uporabnik IMAP",
    "IMAP Password" : "Geslo IMAP",
    "SMTP Settings" : "Nastavitve SMTP",
    "SMTP Host" : "Gostitelj SMTP",
    "SMTP Security" : "Varnost SMTP",
    "SMTP Port" : "Vrata SMTP",
    "SMTP User" : "Uporabnik SMTP",
    "SMTP Password" : "Geslo SMTP",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Za pravilno delovanje poštnega računa Google je treba omogočiti dvostopenjsko overitev in določiti geslo za program.",
    "Account settings" : "Nastavitve računa",
    "Aliases" : "Vzdevki",
    "Signature" : "Podpis",
    "A signature is added to the text of new messages and replies." : "K besedilu novih sporočil in odgovorov je dodan podpis.",
    "Writing mode" : "Način pisanja",
    "Preferred writing mode for new messages and replies." : "Prednostni način pisanja sporočil za nova sporočila in odgovore.",
    "Default folders" : "Privzete mape",
    "Filters" : "Filtri",
    "Mail server" : "Poštni strežnik",
    "Update alias" : "Posodobi vzdevek",
    "Rename alias" : "Preimenuj vzdevek",
    "Show update alias form" : "Pokaži obrazec za posodobitev vzdevka",
    "Delete alias" : "Izbriši vzdevek",
    "Go back" : "Nazaj",
    "Change name" : "Spremeni ime",
    "Email address" : "Elektronski naslov",
    "Add alias" : "Dodaj vzdevek",
    "Create alias" : "Ustvari vzdevek",
    "Cancel" : "Prekliči",
    "Put my text to the bottom of a reply instead of on top of it." : "Dodaj besedilo odgovora pod izvorno sporočilo in ne nad.",
    "Could not update preference" : "Lastnosti ni mogoče posodobiti",
    "Mail settings" : "Nastavitve pošte",
    "Accounts" : "Računi",
    "Add mail account" : "Dodaj račun elektronske pošte",
    "General" : "Splošno",
    "List" : "Seznam",
    "Sorting" : "Razvrščanje",
    "Newest" : "Najnovejše",
    "Oldest" : "Najstarejše",
    "Gravatar settings" : "Nastavitve Gravatar",
    "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
    "Register as application for mail links" : "Nastavi kot program za odpiranje povezav na poštne elektronske naslove",
    "Register" : "Vpis računa",
    "Shared with me" : "V souporabi z mano",
    "Data collection consent" : "Strinjanje z zbiranjem podatkov",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
    "Trusted senders" : "Zaupanja vredni pošiljatelji",
    "Manage S/MIME certificates" : "Upravljanje s potrdili S/MIME",
    "About" : "O meni",
    "Keyboard shortcuts" : "Tipkovne bližnjice",
    "Compose new message" : "Novo sporočilo",
    "Newer message" : "Novejše sporočilo",
    "Older message" : "Starejše sporočilo",
    "Toggle star" : "Preklopi zvezdico",
    "Toggle unread" : "Preklopi neprebrano",
    "Archive" : "Arhiv",
    "Delete" : "Izbriši",
    "Search" : "Iskanje",
    "Send" : "Pošlji",
    "Refresh" : "Osveži",
    "Ok" : "Sprejemljivo",
    "No certificate" : "Ni potrdil",
    "Certificate updated" : "Potrdilo je posodobljeno",
    "Could not update certificate" : "Potrdila ni mogoče posodobiti",
    "{commonName} - Valid until {expiryDate}" : "{commonName} – veljavnost do {expiryDate}",
    "Select an alias" : "Izbor vzdevka",
    "Update Certificate" : "Posodobi potrdilo",
    "Encrypt with S/MIME and send later" : "Šifriraj z S/MIME in pošlji kasneje",
    "Encrypt with S/MIME and send" : "Šifriraj z S/MIME in pošlji",
    "Encrypt with Mailvelope and send later" : "Šifriraj z Mailvelope in pošlji kasneje",
    "Encrypt with Mailvelope and send" : "Šifriraj z Mailvelope in pošlji",
    "Send later" : "Pošlji kasneje",
    "Message {id} could not be found" : "Sporočila {id} ni mogoče najti.",
    "Turn off formatting" : "Onemogoči oblikovanje",
    "Turn off and remove formatting" : "Onemogoči in odstrani oblikovanje",
    "Keep formatting" : "Ohrani oblikovanje",
    "From" : "Od",
    "Select account" : "Izbor računa",
    "To" : "Za",
    "Select recipient" : "Izbor prejemnika",
    "Contact or email address …" : "Stik ali elektronski naslov ...",
    "Cc" : "Kp",
    "Bcc" : "Skp",
    "Subject" : "Zadeva",
    "Subject …" : "Zadeva ...",
    "This message came from a noreply address so your reply will probably not be read." : "Sporočilo je bilo poslano z naslova, ki ni namenjen odgovarjanju, zato odgovor najverjetneje ne bo prispel do naslovnika.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Navedeni uporabniki nimajo ustreznega potrdila S/MIME: {recipients}",
    "The following recipients do not have a PGP key: {recipients}." : "Nekateri prejemniki so brez ključa PGP: {recipients}.",
    "Write message …" : "Besedilo sporočila ...",
    "Saving draft …" : "Poteka shranjevanje osnutka ...",
    "Error saving draft" : "Napaka shranjevanja osnutka",
    "Draft saved" : "Osnutek je shranjen",
    "Save draft" : "Shrani osnutek",
    "Discard & close draft" : "Opusti in zapri osnutek",
    "Enable formatting" : "Omogoči oblikovanje",
    "Disable formatting" : "Onemogoči oblikovanje",
    "Upload attachment" : "Pošlji prilogo",
    "Add attachment from Files" : "Dodaj prilogo iz Datotek",
    "Smart picker" : "Pametni izbirnik",
    "Request a read receipt" : "Zahtevaj povratnico",
    "Sign message with S/MIME" : "Podpiši sporočila z S/MIME",
    "Encrypt message with S/MIME" : "Šifriraj z S/MIME",
    "Encrypt message with Mailvelope" : "Šifriraj sporočilo z Mailvelope",
    "Send now" : "Pošlji takoj",
    "Tomorrow morning" : "Jutri zjutraj",
    "Tomorrow afternoon" : "Jutri popoldne",
    "Monday morning" : "Ponedeljek zjutraj",
    "Custom date and time" : "Datum in čas po meri",
    "Enter a date" : "Vpis datuma ...",
    "Choose" : "Izbor",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Velikost priloge presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave."],
    "Choose a file to add as attachment" : "Izbor datoteke za prilogo",
    "Choose a file to share as a link" : "Izberite datoteko, ki jo želite dati v skupno rabo kot povezavo",
    "_{count} attachment_::_{count} attachments_" : ["{count} priloga","{count} prilogi","{count} priloge","{count} prilog"],
    "Untitled message" : "Nenaslovljeno sporočilo",
    "Confirm" : "Potrdi",
    "Plain text" : "Besedilno",
    "Rich text" : "Obogateno besedilo",
    "No messages in this folder" : "V tej mapi ni sporočil",
    "No messages" : "Ni sporočil",
    "Blind copy recipients only" : "Le prejemniki skrite kopije",
    "No subject" : "Ni zadeve",
    "Later today – {timeLocale}" : "Danes – {timeLocale}",
    "Set reminder for later today" : "Nastavi opomnik za danes",
    "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
    "Set reminder for tomorrow" : "Nastavi opomnik za jutri",
    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
    "Set reminder for this weekend" : "Nastavi opomnik za ta teden",
    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
    "Set reminder for next week" : "Nastavi opomnik za naslednji teden",
    "Could not delete message" : "Sporočila ni mogoče izbrisati",
    "Could not archive message" : "Ni mogoče arhivirati sporočila",
    "Encrypted message" : "Šifrirano sporočilo",
    "This message is unread" : "To sporočilo še ni bilo prebrano",
    "Unfavorite" : "Odstrani oznako priljubljeno",
    "Favorite" : "Priljubljeno",
    "Unread" : "Neprebrano",
    "Read" : "Branje",
    "Unimportant" : "Nepomembno",
    "Mark not spam" : "Označi kot običajno",
    "Mark as spam" : "Označi kot neželeno",
    "Edit tags" : "Uredi oznake",
    "Move thread" : "Premakni nit",
    "Archive thread" : "Nit arhiva",
    "Archive message" : "Arhiviraj sporočilo",
    "Delete thread" : "Izbriši nit",
    "Delete message" : "Izbriši sporočilo",
    "More actions" : "Več dejanj",
    "Back" : "Nazaj",
    "Edit as new message" : "Uredi kot novo sporočilo",
    "Create task" : "Ustvari nalogo",
    "Download message" : "Prejmi sporočilo",
    "Load more" : "Naloži več",
    "_Mark {number} read_::_Mark {number} read_" : ["Označi {number} sporočilo kot prebrano","Označi {number} sporočili kot prebrani","Označi {number} sporočila kot prebrana","Označi {number} sporočil kot prebrana"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Označi {number} sporočilo kot neprebrano","Označi {number} sporočili kot neprebrani","Označi {number} sporočila kot neprebrana","Označi {number} sporočil kot neprebrana"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Odstrani oznako {number} sporočila kot priljubljenega","Odstrani oznako {number} sporočil kot priljubljenih","Odstrani oznako {number} sporočil kot priljubljenih","Odstrani oznako {number} sporočil kot priljubljenih"],
    "_Favorite {number}_::_Favorite {number}_" : ["Označi {number} sporočilo kot priljubljeno","Označi {number} sporočili kot priljubljeni","Označi {number} sporočila kot priljubljena","Označi {number} sporočil kot priljubljena"],
    "_Unselect {number}_::_Unselect {number}_" : ["Odstrani izbiro {number} sporočila","Odstrani izbiro {number} sporočil","Odstrani izbiro {number} sporočil","Odstrani izbiro {number} sporočil"],
    "_Move {number} thread_::_Move {number} threads_" : ["Premakni {number} nit sporočil","Premakni {number} niti sporočil","Premakni {number} niti sporočil","Premakni {number} niti sporočil"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Posreduj {number} sporočilo kot prilogo","Posreduj {number} sporočili kot prilogo","Posreduj {number} sporočila kot prilogo","Posreduj {number} sporočil kot prilogo"],
    "Mark as unread" : "Označi kot neprebrano",
    "Mark as read" : "Označi kot prebrano",
    "Report this bug" : "Pošlji poročilo o hrošču",
    "Event created" : "Dogodek je ustvarjen",
    "Could not create event" : "Ni mogoče ustvariti dogodka",
    "Create event" : "Ustvari dogodek",
    "All day" : "Ves dan",
    "Attendees" : "Udeleženci",
    "Select calendar" : "Izbor koledarja",
    "Description" : "Opis",
    "Create" : "Ustvari",
    "This event was updated" : "Dogodek je posodobljen",
    "{attendeeName} accepted your invitation" : "{attendeeName} sprejme povabilo",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} pogojno sprejme vabilo",
    "{attendeeName} declined your invitation" : "{attendeeName} zavrne povabilo",
    "{attendeeName} reacted to your invitation" : "{attendeeName} se odzove na povabilo",
    "Failed to save your participation status" : "Shranjevanje stanja udeležbe je spodletelo",
    "You accepted this invitation" : "Povabilo ste sprejeli",
    "You tentatively accepted this invitation" : "Vabilo ste sprejeli pogojno",
    "You declined this invitation" : "Povabilo ste zavrnili",
    "You already reacted to this invitation" : "Na to vabilo ste se že odzvali",
    "You have been invited to an event" : "Povabljeni ste na dogodek",
    "This event was cancelled" : "Dogodek je preklican",
    "Save to" : "Shrani v",
    "Select" : "Izbor",
    "Comment" : "Opomba",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "Tentatively accept" : "Pogojno sprejmi",
    "More options" : "Več možnosti",
    "individual" : "posamično",
    "domain" : "domena",
    "Remove" : "Odstrani",
    "email" : "elektronska pošta",
    "Itinerary for {type} is not supported yet" : "{type} – vrsta prevoza še ni podprta",
    "Last hour" : "Zadnja ura",
    "Today" : "Danes",
    "Last week" : "Zadnji teden",
    "Last month" : "Zadnji mesec",
    "Loading messages …" : "Poteka nalaganje sporočil ...",
    "Choose target folder" : "Izbor ciljne mape",
    "No more submailboxes in here" : "V tem predalu ni drugih predalov",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Sporočila bodo samodejno označena kot pomembna na podlagi do sedaj označenih takih sporočil. V začetku bo verjetno treba kakšno označiti še ročno, a se bo sistem s časom izboljševal.",
    "Important info" : "Pomembno",
    "Other" : "Drugo",
    "Could not send mdn" : "Sporočila ni mogoče poslati",
    "The sender of this message has asked to be notified when you read this message." : "Pošiljatelj želi biti obveščen, ko preberete to sporočilo.",
    "Notify the sender" : "Obvesti pošiljatelja",
    "You sent a read confirmation to the sender of this message." : "Poslali ste potrditev pošiljatelju tega sporočila.",
    "Forward" : "Posreduj",
    "Move message" : "Premakni sporočilo",
    "Translate" : "Prevedi",
    "Forward message as attachment" : "Posreduj sporočilo kot prilogo",
    "View source" : "Pokaži kode sporočila",
    "Download thread data for debugging" : "Prejmi podatke niti za razhroščevanje",
    "Message body" : "Telo sporočila",
    "Unnamed" : "Neimenovano",
    "Embedded message" : "Vstavljeno sporočilo",
    "Choose a folder to store the attachment in" : "Izbor mape za shranjevanje priloge",
    "Import into calendar" : "Uvozi v koledar",
    "Download attachment" : "Prejmi prilogo",
    "Save to Files" : "Shrani v Datoteke",
    "View fewer attachments" : "Pokaži manj prilog",
    "Choose a folder to store the attachments in" : "Izbor mape za shranjevanje priloge",
    "Save all to Files" : "Shrani vse v Datoteke",
    "Download Zip" : "Prejmi ZIP",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Sporočilo je šifrirano s programom PGP. Za odšifriranje mora biti nameščen program Mailvelope.",
    "The images have been blocked to protect your privacy." : "Za zaščito zasebnosti je prikaz slik onemogočen.",
    "Show images" : "Pokaži slike",
    "Show images temporarily" : "Pokaži slike začasno",
    "Always show images from {sender}" : "Pokaži slike pošiljatelja {sender}",
    "Always show images from {domain}" : "Pokaži slike z domene {domain}",
    "Message frame" : "Okvir sporočila",
    "Quoted text" : "Navedek besedila",
    "Move" : "Premakni",
    "Moving" : "Premikanje",
    "Moving thread" : "Poteka premikanje niti ...",
    "Moving message" : "Poteka premikanje sporočila ...",
    "Remove account" : "Odstrani račun",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} in podatki tega računa v predpomnilniku bodo odstranjeni iz oblaka Nextcloud, ne pa tudi iz poštnega računa pri ponudniku storitve.",
    "Remove {email}" : "Odstrani {email}",
    "Provisioned account is disabled" : "Povezan račun je onemogočen",
    "Show only subscribed folders" : "Pokaži le naročene mape",
    "Add folder" : "Dodaj mapo",
    "Folder name" : "Ime mape",
    "Saving" : "Poteka shranjevanje ...",
    "Move up" : "Premakni višje",
    "Move down" : "Premakni navzdol",
    "Show all subscribed folders" : "Pokaži vse naročene mape",
    "Show all folders" : "Pokaži vse mape",
    "Collapse folders" : "Zloži mape",
    "_{total} message_::_{total} messages_" : ["{total} sporočilo","{total} sporočili","{total} sporočila","{total} sporočil"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neprebrano od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebranih od skupno {total}"],
    "Loading …" : "Poteka nalaganje …",
    "All messages in mailbox will be deleted." : "Vsa sporočila v poštnem predalu bodo izbrisana.",
    "Clear mailbox {name}" : "Počisti poštni predal {name}",
    "The folder and all messages in it will be deleted." : "Mapa in vsa sporočila bodo izbrisana.",
    "Delete folder" : "Izbriši mapo",
    "Delete folder {name}" : "Izbriši mapo {name}",
    "An error occurred, unable to rename the mailbox." : "Prišlo je do napake; poštnega predala ni mogoče preimenovati.",
    "Mark all as read" : "Označi vse kot prebrano",
    "Mark all messages of this folder as read" : "Označi vsa sporočila v tej mapi kot prebrana",
    "Add subfolder" : "Dodaj podmapo",
    "Rename" : "Preimenuj",
    "Move folder" : "Premakni mapo",
    "Clear cache" : "Počisti predpomnilnik",
    "Clear locally cached data, in case there are issues with synchronization." : "Počisti krajevno predpomnjena sporočila, v primeru morebitnih težav z usklajevanjem.",
    "Subscribed" : "Naročeno",
    "Sync in background" : "Uskladi v ozadju",
    "Outbox" : "Odhodna pošta",
    "New message" : "Novo sporočilo",
    "Edit message" : "Uredi sporočilo",
    "Draft" : "Osnutek",
    "Reply" : "Odgovori",
    "Message saved" : "Sporočilo je shranjeno",
    "Failed to save message" : "Shranjevanje sporočila je spodletelo",
    "Failed to save draft" : "Shranjevanje osnutka je spodletelo",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Poskušate poslati prevelikemu številu naslovnikov in prejemnikov kopije sporočila. Razmislite o uporabi skrite kopije za izbrane naslove.",
    "Message discarded" : "Sporočilo je izbrisano",
    "Could not discard message" : "Sporočila ni mogoče zavreči",
    "Error sending your message" : "Prošlo je do napake med pošiljanjem sporočila",
    "Retry" : "Poskusi  znova",
    "Warning sending your message" : "Opozorilo pred pošiljanjem sporočila",
    "Send anyway" : "Pošlji vseeno",
    "First day" : "Prvi dan",
    "Last day (optional)" : "Zadnji dan (izbirno)",
    "Message" : "Sporočilo",
    "Oh Snap!" : "Ojoj!",
    "Could not open outbox" : "Ni mogoče odpreti odhodnega predala",
    "Message could not be sent" : "Sporočila ni mogoče poslati",
    "Message deleted" : "Sporočilo je izbrisano",
    "Copied email address to clipboard" : "Elektronski naslov je kopiran v odložišče",
    "Could not copy email address to clipboard" : "Elektronskega naslova ni mogoče kopirati v odložišče",
    "Contacts with this address" : "Stiki s tem naslovom",
    "Add to Contact" : "Dodaj k stiku",
    "New Contact" : "Nov stik",
    "Copy to clipboard" : "Kopiraj v odložišče",
    "Contact name …" : "Ime stika …",
    "Add" : "Dodaj",
    "Show less" : "Pokaži manj",
    "Show more" : "Pokaži več",
    "Clear" : "Počisti",
    "Close" : "Zapri",
    "Search parameters" : "Poišči parametre",
    "Body" : "Besedilo",
    "Date" : "Datum",
    "Pick a start date" : "Izbor datuma začetka",
    "Pick an end date" : "Izbor datuma konca",
    "Select senders" : "Izbor pošiljateljev",
    "Select recipients" : "Izbor prejemnikov",
    "Select CC recipients" : "Izbor prejemnikov v kopiji",
    "Select BCC recipients" : "Izbor skritih prekemnikov",
    "Tags" : "Oznake",
    "Select tags" : "Izbor oznak",
    "Marked as" : "Označeno kot",
    "Has attachments" : "Vsebuje prilogo",
    "Last 7 days" : "Zadnjih 7 dni",
    "Sieve Port" : "Vrata Sieve",
    "Custom" : "Po meri",
    "Sieve User" : "Uporabnik Sieve",
    "Sieve Password" : "Geslo Sieve",
    "Save sieve settings" : "Shrani nastavitve sieve",
    "The syntax seems to be incorrect:" : "Skladnja je videti nepravilna:",
    "Save sieve script" : "Shrani skript sieve",
    "Signature …" : "Podpis ...",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Nastavljen podpis je večji od 2 MB. Velikost lahko vpliva na delovanje urejevalnika.",
    "Save signature" : "Shrani podpis",
    "Place signature above quoted text" : "Postavi podpis nad navedeno besedilo.",
    "Message source" : "Vir sporočila",
    "An error occurred, unable to rename the tag." : "Prišlo je do napake, oznake ni mogoče preimenovati.",
    "Saving new tag name …" : "Poteka shranjevanje imena oznake ...",
    "Delete tag" : "Izbriši oznako",
    "Set tag" : "Nastavi oznako",
    "Unset tag" : "Odstrani oznako",
    "Tag name is a hidden system tag" : "Ime oznake je skrita sistemska oznaka",
    "Tag already exists" : "Oznaka že obstaja",
    "An error occurred, unable to create the tag." : "Prišlo je do napake, oznake ni mogoče ustvariti.",
    "Add default tags" : "Dodaj privzete oznake",
    "Add tag" : "Dodaj oznako",
    "Saving tag …" : "Poteka shranjevanje ozake ...",
    "Task created" : "Naloga je ustvarjena",
    "Could not create task" : "Naloge ni mogoče ustvariti",
    "No calendars with task list support" : "Koledar s podporo seznama nalog",
    "Could not load your message thread" : "Ni mogoče naložiti niti sporočil",
    "The thread doesn't exist or has been deleted" : "Nit ne obstaja ali pa je bila izbrisana",
    "Loading thread" : "Poteka nalaganje niti",
    "Not found" : "Predmeta ni mogoče najti",
    "Encrypted & verified " : "Šifrirano in overjeno",
    "Signature verified" : "Podpis je overjen",
    "Signature unverified " : "Podpis ni overjen",
    "Reply all" : "Odgovori vsem",
    "Unsubscribe" : "Prekliči naročnino",
    "Reply to sender only" : "Odgovori le pošiljatelju",
    "Mark as unfavorite" : "Odstrani oznako priljubljeno",
    "Mark as favorite" : "Označi kot priljubljeno",
    "The message could not be translated" : "Sporočila ni mogoče prevesti",
    "Translation copied to clipboard" : "Prevod je kopiran v odložišče",
    "Translation could not be copied" : "Prevoda ni mogoče kopirati!",
    "Translate message" : "Prevedi sporočilo",
    "Source language to translate from" : "Izvorni jezik za prevod",
    "Translate from" : "Prevedi iz",
    "Target language to translate into" : "Ciljni jezik za prevod",
    "Translate to" : "Prevedi v",
    "Translating" : "Poteka prevajanje",
    "Copy translated text" : "Kopiraj prevedeno besedilo",
    "Could not remove trusted sender {sender}" : "Ni mogoče odstraniti zanesljivega pošiljatelja {sender}",
    "No senders are trusted at the moment." : "Ni še zavedenih zaupanja vrednih pošiljateljev.",
    "Untitled event" : "Neimenovan dogodek",
    "(organizer)" : " (skliče dogodek)",
    "Import into {calendar}" : "Uvozi v koledar {calendar}",
    "Event imported into {calendar}" : "Dogodek je uvožen v koledar {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Let {flightNr} iz {depAirport} na letališče {arrAirport}",
    "Airplane" : "Letalo",
    "Reservation {id}" : "Rezervacija {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} v {arrStation}",
    "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} v {arrStation}",
    "Train" : "Vlak",
    "Recipient" : "Prejemnik",
    "Delete filter" : "Izbriši filter",
    "Help" : "Pomoč",
    "contains" : "vsebuje",
    "matches" : "se sklada z",
    "Actions" : "Dejanja",
    "Priority" : "Prednost",
    "Tag" : "Oznaka",
    "delete" : "izbriši",
    "Edit" : "Uredi",
    "Successfully updated config for \"{domain}\"" : "Nastavitve za domeno »{domain}« so uspešno posodobljene.",
    "Error saving config" : "Napaka shranjevanja nastavitev",
    "Saved config for \"{domain}\"" : "Nastavitve za domeno »{domain}« so shranjene.",
    "Could not save provisioning setting" : "Ni mogoče shraniti nastavitev povezovanja",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Uspešno je zaključeno povezovanje {count} računa.","Uspešno je zaključeno povezovanje {count} računov.","Uspešno je zaključeno povezovanje {count} računov.","Uspešno je zaključeno povezovanje {count} računov."],
    "There was an error when provisioning accounts." : "Prišlo je do napake med povezovanjem računov.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Brisanje in odstranjevanje povezovanja računov za »{domain}« je uspešno končano.",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Napaka pri brisanju in odstranjevanju povezovanja računov za »{domain}«",
    "Mail app" : "Program Pošta",
    "The mail app allows users to read mails on their IMAP accounts." : "Program Mail omogoča uporabnikom branje sporočil z računov IMAP.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Na tem mestu so zbrane nastavitve celotnega okolja. Uporabniške nastavitve so v posameznem programu (spodnji levi kot).",
    "Account provisioning" : "Povezovanje računov",
    "A provisioning configuration will provision all accounts with a matching email address." : "Nastavitve povezovanja zagotavljajo povezovanje vseh računov s skladnim elektronskim naslovom.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Uporaba nadomestnih znakov (*) v polju priprave domene ustvari nastavitev, ki je nato uveljavljena za vse uporabnike, če za posemeznike niso v veljavi druge nastavitve.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Mehanizem za povezovanje prednostno privzame nastavitve domen pred nastavitvami z uporabo nadomestnih znakov.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Če bo ustvarjena nova nastavitev po tem, ko je bil uporabnik že povezan, bo imela prednostno uporabljena novejša nastavitev, uporabnik pa bo ponovno povezan v nov sistem.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Če želite ponuditi eno domeno vsem uporabnikom, to zapišite z nadomestnimi znaki (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Nastavitev je smiselna le, če v ustanovi uporabljate isto uporabniško zaledje za Nextcloud in poštni strežnik.",
    "Provisioning Configurations" : "Nastavitve povezovanja računov",
    "Add new config" : "Dodaj nove nastavitve",
    "Provision all accounts" : "Zagotovi povezanost vseh računov",
    "Anti Spam Service" : "Storitve proti neželeni pošti",
    "You can set up an anti spam service email address here." : "Določiti je mogoče elektronski naslov za storitve neželenih sporočil.",
    "Gmail integration" : "Združevalnik Gmail",
    "Anti Spam" : "Anti Spam",
    "\"Mark as Spam\" Email Address" : "Označi sporočila z elektronskega naslova kot »Neželena sporočila«",
    "\"Mark Not Junk\" Email Address" : "Označi sporočila z elektronskega naslova kot »Niso neželena sporočila«",
    "Reset" : "Ponastavi",
    "Client ID" : "ID Odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "Unlink" : "Odstrani povezavo",
    "Domain Match: {provisioningDomain}" : "Skladna domena: {provisioningDomain}",
    "Email: {email}" : "Elektronski naslov: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} na {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} na {host}:{port} ({ssl} encryption)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} na {host}:{port} (šifriranje {ssl})",
    "Configuration for \"{provisioningDomain}\"" : "Nastavitve za »{provisioningDomain}«",
    "Provisioning domain" : "Domena za povezovanje",
    "Email address template" : "Predloga elektronskega naslova",
    "IMAP" : "IMAP",
    "User" : "Uporabnik",
    "Host" : "Gostitelj",
    "Port" : "Vrata",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Omogoči združevalnik sieve",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "PRogram LDAP pridobi podatke atributa, nastavljenega v imeniku LDAP za povezovanje elektronskih naslovov z vzdevki.",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Nastavitev določa atribut z več vrednostmi za povezovanje vzdevkov elektronskih naslovov. Za vsako vrednost je ustvarjen vzdevek, tisti vzdevki, ki so vpisani v oblaku Nextcloud, a niso tudi v imeniku LDAP, se izbrišejo.",
    "Save Config" : "Shrani nastavitve",
    "Unprovision & Delete Config" : "Odstrani povezavo in izbriši nastavitve",
    "With the settings above, the app will create account settings in the following way:" : "Z zgornjo nastavitvijo bo ustvarjen račun s podatki:",
    "Failed to import the certificate" : "Uvažanje potrdila je spodletelo",
    "S/MIME certificates" : "Potrdila S/MIME",
    "Certificate name" : "Ime potrdila",
    "E-mail address" : "Naslov elektronske pošte",
    "Valid until" : "Veljavno do",
    "Delete certificate" : "Izbriši potrdilo",
    "No certificate imported yet" : "Ni še uvoženih potrdil",
    "Import certificate" : "Uvozi potrdilo",
    "Import S/MIME certificate" : "Uvozi potrdila S/MIME",
    "PKCS #12 Certificate" : "Potrdilo PKCS #12",
    "PEM Certificate" : "Potrdilo PEM",
    "Certificate" : "Potrdilo",
    "Private key (optional)" : "Zasebni ključ (izbirno)",
    "Submit" : "Pošlji",
    "Group" : "Skupina",
    "Shared" : "V souporabi",
    "Shares" : "V souporabi",
    "Insert" : "Vstavi",
    "Account connected" : "Račun je povezan",
    "Connect your mail account" : "Povežite svoj elektronski račun",
    "All" : "Vse",
    "Drafts" : "Osnutki",
    "Favorites" : "Priljubljene",
    "Priority inbox" : "Prednostni dohodni predal",
    "All inboxes" : "Vsi predali",
    "Inbox" : "Prejeto",
    "Junk" : "Neželena pošta",
    "Sent" : "Poslano",
    "Trash" : "Smeti",
    "Connect OAUTH2 account" : "Poveži račun z overitvijo OAUTH2",
    "Error while sharing file" : "Prišlo je do napake med souporabo datoteke",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n novo sporočilo \npošilja {from}","%n novi sporočili \npošilja {from}","%n nova sporočila \npošilja {from}","%n novih sporočil \npošilja {from}"],
    "Nextcloud Mail" : "Pošta Nextcloud Mail",
    "Discard changes" : "Opusti spremembe",
    "Discard unsaved changes" : "Opusti neshranjene spremembe",
    "Keep editing message" : "Nadaljuj z urejanjem sporočila",
    "Attachments were not copied. Please add them manually." : "Priloge niso bile kopirane. Dodati jih je treba ročno.",
    "Message sent" : "Sporočilo je poslano",
    "Could not send message" : "Ni mogoče poslati sporočila",
    "Could not load {tag}{name}{endtag}" : "Ni mogoče naložiti {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Prišlo je do napake pri nalaganju {tag}{name}{endtag}",
    "Could not load your message" : "Sporočila ni mogoče naložiti",
    "Could not load the desired message" : "Želenega sporočila ni mogoče naložiti",
    "Could not load the message" : "Sporočila ni mogoče naložiti",
    "Error loading message" : "Napaka nalaganja sporočila",
    "Forwarding to %s" : "Poteka posredovanje sporočila za %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Če vas sistem v nekaj sekundah ne preusmeri samodejno, pritisnite na to mesto.",
    "Redirect" : "Preusmeri",
    "The link leads to %s" : "Povezava vodi do %s",
    "Continue to %s" : "Nadaljuj na %s"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
